==> openshift-model-hive-5.12.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterPoolConditionBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ClusterPoolConditionBuilder extends io.fabric8.openshift.api.model.hive.v1.ClusterPoolConditionFluentImpl<io.fabric8.openshift.api.model.hive.v1.ClusterPoolConditionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.ClusterPoolCondition,io.fabric8.openshift.api.model.hive.v1.ClusterPoolConditionBuilder>{
  public ClusterPoolConditionBuilder() {
    this(false);
  }
  public ClusterPoolConditionBuilder(java.lang.Boolean validationEnabled) {
    this(new ClusterPoolCondition(), validationEnabled);
  }
  public ClusterPoolConditionBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterPoolConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterPoolConditionBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterPoolConditionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ClusterPoolCondition(), validationEnabled);
  }
  public ClusterPoolConditionBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterPoolConditionFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.ClusterPoolCondition instance) {
    this(fluent, instance, false);
  }
  public ClusterPoolConditionBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterPoolConditionFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.ClusterPoolCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastProbeTime(instance.getLastProbeTime()); 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterPoolConditionBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterPoolCondition instance) {
    this(instance,false);
  }
  public ClusterPoolConditionBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterPoolCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastProbeTime(instance.getLastProbeTime()); 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.ClusterPoolConditionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.ClusterPoolCondition build() {
    ClusterPoolCondition buildable = new ClusterPoolCondition(fluent.getLastProbeTime(),fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterPoolConditionBuilder that = (ClusterPoolConditionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.5.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterPoolConditionBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterPoolConditionBuilder extends ClusterPoolConditionFluentImpl<ClusterPoolConditionBuilder> implements VisitableBuilder<ClusterPoolCondition,ClusterPoolConditionBuilder>{
  public ClusterPoolConditionBuilder() {
    this(false);
  }
  public ClusterPoolConditionBuilder(Boolean validationEnabled) {
    this(new ClusterPoolCondition(), validationEnabled);
  }
  public ClusterPoolConditionBuilder(ClusterPoolConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterPoolConditionBuilder(ClusterPoolConditionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterPoolCondition(), validationEnabled);
  }
  public ClusterPoolConditionBuilder(ClusterPoolConditionFluent<?> fluent,ClusterPoolCondition instance) {
    this(fluent, instance, false);
  }
  public ClusterPoolConditionBuilder(ClusterPoolConditionFluent<?> fluent,ClusterPoolCondition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastProbeTime(instance.getLastProbeTime()); 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterPoolConditionBuilder(ClusterPoolCondition instance) {
    this(instance,false);
  }
  public ClusterPoolConditionBuilder(ClusterPoolCondition instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastProbeTime(instance.getLastProbeTime()); 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ClusterPoolConditionFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterPoolCondition build() {
    ClusterPoolCondition buildable = new ClusterPoolCondition(fluent.getLastProbeTime(),fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
